@@ -7,7 +7,7 @@ from .native import lib, ffi
 import platform
 
 is_pypy = platform.python_implementation() == "PyPy"
-from .tasks import create_task, create_task_with_factory
+from .tasks import create_task, TaskFactory
 import sys
 import logging
 
@@ -351,18 +351,17 @@ class _WSGI:
             # internally will still use custom task factory for pypy because of Loop
             if is_pypy:
                 if task_factory_max_items > 0:
-                    factory = create_task_with_factory(task_factory_max_items)
+                    factory = TaskFactory(task_factory_max_items)
 
                     def run_task(task):
                         factory(loop, task)
-                        loop._run_once()
 
                     self._run_task = run_task
                 else:
 
                     def run_task(task):
-                        create_task(loop, task)
-                        loop._run_once()
+                        future = create_task(loop, task)
+                        future._log_destroy_pending = False
 
                     self._run_task = run_task
 
@@ -370,15 +369,15 @@ class _WSGI:
                 if sys.version_info >= (3, 8):  # name fixed to avoid dynamic name
 
                     def run_task(task):
-                        loop.create_task(task, name="socketify.py-request-task")
-                        loop._run_once()
+                        future = create_task(loop, task)
+                        future._log_destroy_pending = False
 
                     self._run_task = run_task
                 else:
 
                     def run_task(task):
-                        loop.create_task(task)
-                        loop._run_once()
+                        future = create_task(loop, task)
+                        future._log_destroy_pending = False
 
                     self._run_task = run_task
 
@@ -501,7 +500,7 @@ class WSGI:
         return self
 
     def run(self, workers=1):
-        def run_app():
+        def run_task():
             server = _WSGI(
                 self.app,
                 self.options,
@@ -514,15 +513,20 @@ class WSGI:
                 server.listen(port_or_options, handler)
             server.run()
 
-        def create_fork():
-            n = os.fork()
-            # n greater than 0 means parent process
-            if not n > 0:
-                run_app()
-
+        pid_list = []
         # fork limiting the cpu count - 1
-        for i in range(1, workers):
-            create_fork()
+        for _ in range(1, workers):
+            pid = os.fork()
+            # n greater than 0 means parent process
+            if not pid > 0:
+                run_task()
+                break
+            pid_list.append(pid)
 
-        run_app()  # run app on the main process too :)
+        run_task()  # run app on the main process too :)
+
+        # sigint everything to gracefull shutdown
+        import signal
+        for pid in pid_list:
+            os.kill(pid, signal.SIGINT)
         return self
